eps = 0.01;

thickness = 5.5;
width = 120;
length = width;
height = 55;

hole_height = thickness/2 + 0.5;
hole_width = thickness/2;
hole_length = 20;

m3_hole_dia = 2.7;
m3_hole_height = thickness*2;

top_text_top_offset=8;
top_text_left_offset=14;
top_text = "R2AUK";
font_name = "Droid Sans Mono";
font_size = 20;
font_size_back = 8;

coil_t = 2;
coil_dia = 43;
coil_len = 80;

dia_l = 9.5;
dia_l_small = 4;
l_small_offset = 12;
dia_c = 9;
dia_s = 12;

offset_l = 2+coil_dia/2;
offset_c_left = 23;
offset_c_bottom = 23;
c_hole_dia = 3.5;
c_hole_offset = 16.5;
c_hole_z_offset = 1.75;

side_hole_dia = 3;

angle_thickness = 2;
angle_height = height*0.75;
angle_width = (width-coil_len-thickness*2-angle_thickness*2)/2;

module so239() {
    // SO239 info according to https://static.chipdip.ru/lib/249/DOC000249075.pdf
    front_d = 16;
    front_off = 18.8;
    front_hole_d = 3.2;
    translate([0, 0, 0]) rotate([90,0,0])
        cylinder(d=front_d,h=20, $fn=100, center=true);
    
    translate([-front_off/2, 0, -front_off/2]) rotate([90,0,0])
        cylinder(d=front_hole_d,h=20,$fn=100, center=true);
    
    translate([front_off/2, 0, -front_off/2]) rotate([90,0,0])
        cylinder(d=front_hole_d,h=20,$fn=100, center=true);
    
    translate([front_off/2, 0, front_off/2]) rotate([90,0,0])
        cylinder(d=front_hole_d,h=20,$fn=100, center=true);
    
    translate([-front_off/2, 0, front_off/2]) rotate([90,0,0])
        cylinder(d=front_hole_d,h=20,$fn=100, center=true);
}

module side_holes() {
    /*
    translate([0, width/2-width/8, height/2+height/8]) rotate([0, 90, 0])
        cylinder(d = side_hole_dia, h = width*2, $fn = 100, center=true);
    translate([0, -width/2+width/8, height/2+height/8]) rotate([0, 90, 0])
        cylinder(d = side_hole_dia, h = width*2, $fn = 100, center=true);
    translate([0, width/2-width/8, height/2-height/8]) rotate([0, 90, 0])
        cylinder(d = side_hole_dia, h = width*2, $fn = 100, center=true);
    translate([0, -width/2+width/8, height/2-height/8]) rotate([0, 90, 0])
        cylinder(d = side_hole_dia, h = width*2, $fn = 100, center=true);
    */
}

/*
module angle() {
    translate([-width/2+angle_width/2+thickness, -width/2+angle_width+thickness, height/2]) union() {
        cube([angle_width, angle_thickness, angle_height], center=true);
        translate([-angle_width/2+angle_thickness/2, -angle_width/2+angle_thickness/2, 0])
            rotate([0, 0, 90])
                cube([angle_width, angle_thickness, angle_height], center=true);
    }
}
*/

module two_holes(delta) {
    translate([0, 0, (thickness-hole_height)/2 + eps]) {
        translate([width/2-hole_width/2-thickness/2,  length/2-hole_length, 0])
            cube([hole_width+delta, hole_length+delta, hole_height], center=true);
        translate([width/2-hole_width/2-thickness/2,  -length/2+hole_length, 0])
            cube([hole_width+delta, hole_length+delta, hole_height], center=true);
    }
}

module top_hole() {
    translate([(width-thickness)/2, (length-thickness)/2, height-thickness/2- m3_hole_height/2+eps])
        cylinder(h=m3_hole_height, d=m3_hole_dia, center=true, $fn=100); 
}

module box_side() {
    difference() {
        union() {
            translate([(width-thickness)/2, thickness/2 + 0.5/2, height/2])
                cube([thickness, length-thickness-0.5, height-thickness], center=true);
            two_holes(-0.5);
        }
        
        top_hole();
    }
}

module bottom() {
    difference() {
        cube([width, length, thickness], center=true);
        rotate([0,0,   0]) two_holes(0.5);
        rotate([0,0,  90]) two_holes(0.5);
        rotate([0,0, 180]) two_holes(0.5);
        rotate([0,0, 270]) two_holes(0.5);
    }
}

module right_side() {
    difference() {
        rotate([0,0,   0]) box_side();
        side_holes();
    }
}

module back_side() {
    difference() {
        rotate([0,0,  90]) box_side();
        translate([0, width/2, height/2]) {
            translate([-width/4, 0, 0]) so239();
            translate([width/4, 0, 0]) so239();
        }
        /*
        translate([-19.5, width/2-thickness/2, height/2+font_size/2+4.5])
            rotate([90, 0, 180]) linear_extrude(height=thickness/2+eps)
                text(text="ANT", font=font_name, size=font_size_back);
        
        translate([41, width/2-thickness/2, height/2+font_size/2+4.5])
            rotate([90, 0, 180]) linear_extrude(height=thickness/2+eps)
                text(text="TRX", font=font_name, size=font_size_back);
        */
        
    }
}

module left_side() {
    difference() {
        rotate([0,0, 180]) box_side();
        side_holes();
    }
}

module front_side() {
    difference() {
        rotate([0,0, 270]) box_side();
        translate([-thickness/2, 0, height/2]) rotate([90, 0, 0])
            cylinder(d = dia_s, h = width*2, $fn=100, center=true);
        translate([-width/2+thickness+offset_l, 0, height/2]) rotate([90, 0, 0])
            cylinder(d = dia_l, h = width*2, $fn=100, center=true);
        translate([-width/2+thickness+offset_l, -width/2+thickness-2.2, height/2+l_small_offset])
            rotate([90,0,0]) cylinder(d = dia_l_small, h = thickness*0.85, $fn=100, center=true);
        translate([width/2-thickness-offset_c_left, 0, offset_c_bottom+thickness/2]) rotate([90, 0, 0])
            cylinder(d = dia_c, h = width*2, $fn=100, center=true);
        
        translate([width/2-thickness-offset_c_left-c_hole_offset, 0, offset_c_bottom+thickness/2+c_hole_z_offset])
            rotate([90,0,0]) cylinder(d = c_hole_dia, h = width*2, $fn=100, center=true);
        translate([width/2-thickness-offset_c_left+c_hole_offset, 0, offset_c_bottom+thickness/2+c_hole_z_offset])
            rotate([90,0,0]) cylinder(d = c_hole_dia, h = width*2, $fn=100, center=true);
    }
}

module top() {
    difference() {
        translate([0, 0, height])
            cube([width, length, thickness], center=true);
    
        translate([0,0,m3_hole_height/2]) {
            rotate([0,0,   0]) top_hole();
            rotate([0,0,  90]) top_hole();
            rotate([0,0, 180]) top_hole();
            rotate([0,0, 270]) top_hole();
        }
    
        translate([-width/2+top_text_left_offset, -top_text_top_offset, height])
            linear_extrude(height=thickness/2+eps)
                #text(text=top_text, font=font_name, size=font_size);
    }
}

module coil() {
    translate([-width/2+coil_dia/2+thickness, 0, height/2]) rotate([90,0,0])
    difference() {
        cylinder(h = coil_len, d = coil_dia, $fn=100, center=true);
        cylinder(h = coil_len+eps, d = coil_dia-coil_t*2, $fn=100, center=true);
    }
}

/* angle(); */

bottom();
right_side();
%back_side();
left_side();
front_side();
coil();
%top();